==> enterprisemodules-ora_config-3.20.0.tar.gz: enterprisemodules-ora_config-3.20.0/lib/puppet/type/ora_audit_policy.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../.."))
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../../../../easy_type/lib"))
require 'easy_type'
require 'puppet_x/enterprisemodules/oracle/access'
require 'puppet_x/enterprisemodules/oracle/title_parser'
require 'puppet_x/enterprisemodules/oracle/default_sid'

# @nodoc
module Puppet
  Type.newtype(:ora_audit_policy) do
    include EasyType
    include Puppet_X::EnterpriseModules::Oracle::Access
    extend Puppet_X::EnterpriseModules::Oracle::TitleParser
    include Puppet_X::EnterpriseModules::Oracle::DefaultSid

    desc <<-DESC
    This resource allows you to manage the Unified Audit policies. This
    Puppet type supports managing the next policy types:

    - privileges
    - roles
    - actions (Anly standard actions)
    - object (only partly)

    Here is an example on how to use this:

        ora_audit_policy { 'ORA_DATABASE_PARAMETER@TEST':
          ensure   => 'present',
          actions  => ['ALTER DATABASE', 'ALTER SYSTEM', 'CREATE SPFILE'],
        }

    DESC

    to_get_raw_resources do
      sql_on_all_primary_database_sids(template('ora_config/ora_audit_policy/index.sql.erb', binding))
    end

    map_title_to_sid(:policy_name)

    #
    # Determine if the policy already exists. We need this because an object action policy
    # might already exist with the same name. In that case Oracle needs an alter statement instead
    # of a create statement.
    #
    def policy_exists?
      sql("select * from AUDIT_UNIFIED_POLICIES WHERE POLICY_NAME = '#{policy_name}'", :sid => sid).any?
    end

    on_create do
      if policy_exists?
        sql("alter audit policy #{policy_name} #{changes}", :sid => sid)
        nil
      else
        [:sql, "create audit policy #{policy_name} ", { :sid => sid }]
      end
    end

    on_modify do
      sql("alter audit policy #{policy_name} #{changes}", :sid => sid)
      nil
    end

    def changes
      privileges             = properties.find { |p| p.name == :privileges }
      privileges_to_drop     = privileges&.to_drop()
      privileges_to_add      = privileges&.to_add()
      actions                = properties.find { |p| p.name == :actions }
      actions_to_drop        = actions&.to_drop()
      actions_to_add         = actions&.to_add()
      roles                  = properties.find { |p| p.name == :roles }
      roles_to_drop          = roles&.to_drop()
      roles_to_add           = roles&.to_add()
      # object_actions         = properties.find {|p| p.name == :object_actions}
      # object_actions_to_drop = object_actions&.to_drop()
      # object_actions_to_add  = object_actions&.to_add()

      changes = ''
      if privileges_to_add&.any? || actions_to_add&.any? || roles_to_add&.any?
        changes += 'add '
        changes += "privileges #{privileges_to_add.join(',')} " if privileges_to_add&.any?
        changes += "actions #{actions_to_add.join(',')} " if actions_to_add&.any?
        changes += "roles #{roles_to_add.join(',')} " if roles_to_add&.any?
      end
      if privileges_to_drop&.any? || actions_to_drop&.any? || roles_to_drop&.any?
        changes += 'drop '
        changes += "privileges #{privileges_to_drop.join(',')} " if privileges_to_drop&.any?
        changes += "actions #{actions_to_drop.join(',')} " if actions_to_drop&.any?
        changes += "roles #{roles_to_drop.join(',')} " if roles_to_drop&.any?
      end
      changes
    end

    on_destroy do
      [:sql, "drop audit policy #{policy_name} ", { :sid => sid }]
    end

    ensurable

    parameter :name
    parameter :policy_name
    parameter :sid

    property :privileges
    property :roles
    property :actions

    # No support yet for object policies
    # property :object_actions
    # property :object_name
    # property :object_schema
    # property :object_type
  end
end

==> enterprisemodules-ora_config-3.25.0.tar.gz: enterprisemodules-ora_config-3.25.0/lib/puppet/type/ora_audit_policy.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../.."))
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../../../../easy_type/lib"))
require 'easy_type'
require 'puppet_x/enterprisemodules/oracle/access'
require 'puppet_x/enterprisemodules/oracle/title_parser'
require 'puppet_x/enterprisemodules/oracle/default_sid'

# @nodoc
module Puppet
  Type.newtype(:ora_audit_policy) do
    include EasyType
    include PuppetX::EnterpriseModules::Oracle::Access
    extend PuppetX::EnterpriseModules::Oracle::TitleParser
    include PuppetX::EnterpriseModules::Oracle::DefaultSid

    desc <<-DESC
    This resource allows you to manage the Unified Audit policies. This
    Puppet type supports managing the next policy types:

    - privileges
    - roles
    - actions (Anly standard actions)
    - object (only partly)

    Here is an example on how to use this:

        ora_audit_policy { 'ORA_DATABASE_PARAMETER@TEST':
          ensure   => 'present',
          actions  => ['ALTER DATABASE', 'ALTER SYSTEM', 'CREATE SPFILE'],
        }

    DESC

    to_get_raw_resources do
      sql_on_all_primary_database_sids(template('ora_config/ora_audit_policy/index.sql.erb', binding))
    end

    map_title_to_sid(:policy_name)

    #
    # Determine if the policy already exists. We need this because an object action policy
    # might already exist with the same name. In that case Oracle needs an alter statement instead
    # of a create statement.
    #
    def policy_exists?
      sql("select * from AUDIT_UNIFIED_POLICIES WHERE POLICY_NAME = '#{policy_name}'", :sid => sid).any?
    end

    on_create do
      if policy_exists?
        sql("alter audit policy #{policy_name} #{changes}", :sid => sid)
        nil
      else
        [:sql, "create audit policy #{policy_name} ", { :sid => sid }]
      end
    end

    on_modify do
      sql("alter audit policy #{policy_name} #{changes}", :sid => sid)
      nil
    end

    def changes
      privileges             = properties.find { |p| p.name == :privileges }
      privileges_to_drop     = privileges&.to_drop()
      privileges_to_add      = privileges&.to_add()
      actions                = properties.find { |p| p.name == :actions }
      actions_to_drop        = actions&.to_drop()
      actions_to_add         = actions&.to_add()
      roles                  = properties.find { |p| p.name == :roles }
      roles_to_drop          = roles&.to_drop()
      roles_to_add           = roles&.to_add()
      # object_actions         = properties.find {|p| p.name == :object_actions}
      # object_actions_to_drop = object_actions&.to_drop()
      # object_actions_to_add  = object_actions&.to_add()

      changes = ''
      if privileges_to_add&.any? || actions_to_add&.any? || roles_to_add&.any?
        changes += 'add '
        changes += "privileges #{privileges_to_add.join(',')} " if privileges_to_add&.any?
        changes += "actions #{actions_to_add.join(',')} " if actions_to_add&.any?
        changes += "roles #{roles_to_add.join(',')} " if roles_to_add&.any?
      end
      if privileges_to_drop&.any? || actions_to_drop&.any? || roles_to_drop&.any?
        changes += 'drop '
        changes += "privileges #{privileges_to_drop.join(',')} " if privileges_to_drop&.any?
        changes += "actions #{actions_to_drop.join(',')} " if actions_to_drop&.any?
        changes += "roles #{roles_to_drop.join(',')} " if roles_to_drop&.any?
      end
      changes
    end

    on_destroy do
      [:sql, "drop audit policy #{policy_name} ", { :sid => sid }]
    end

    ensurable

    parameter :name
    parameter :policy_name
    parameter :sid

    property :privileges
    property :roles
    property :actions

    # No support yet for object policies
    # property :object_actions
    # property :object_name
    # property :object_schema
    # property :object_type
  end
end
